@@ -27,7 +27,16 @@ https://docs.djangoproject.com/en/3.1/howto/deployment/wsgi/
 import os
 
 from django.core.wsgi import get_wsgi_application
+from whitenoise import WhiteNoise
+
+from compose.conf.settings import STATIC_ROOT
 
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "compose.conf.settings")
 
+
 application = get_wsgi_application()
+
+application = WhiteNoise(
+    application,
+    root=STATIC_ROOT,
+)
